@@ -14,8 +14,8 @@ use zerocopy::{AsBytes, FromBytes, LayoutVerified};
 
 pub type PubkeyBuffer = [u8; 32];
 
-#[repr(C)]
 #[derive(Default,AsBytes,FromBytes,Clone,Debug)]
+#[repr(C)]
 pub struct FastRoundResult {
     pub num_success: i32,
     pub num_error: i32,
@@ -26,26 +26,22 @@ pub struct FastRoundResult {
     pub max_response: f64,
 }
 
-#[repr(C)]
 #[derive(Default,AsBytes,FromBytes,Clone,Debug)]
+#[repr(C)]
 pub struct FastRoundResultAccountData {
     pub parent: PubkeyBuffer,
     pub result: FastRoundResult,
 }
 
+// REQUIRES THE ENTIRE BUFFER, WITH TYPE BYTE
 pub fn fast_from_bytes<T: Sized + AsBytes + FromBytes + Clone>(bytes: &[u8])
- -> Result<T, ProgramError> {
-     msg!("cc1");
-     let len = std::mem::size_of::<T>();
-     msg!("cc2");
-     let mut buf = vec![0u8;len];
-     msg!("cc3");
-     buf.copy_from_slice(&bytes[..len]);
-     msg!("cc4");
-     let (res, _) = LayoutVerified::<&[u8], T>::new_from_prefix(&buf)
-         .ok_or(ProgramError::InvalidAccountData)?;
-     msg!("cc5");
-     return Ok(res.clone());
+-> Result<T, ProgramError> {
+    let len = std::mem::size_of::<T>();
+    let mut buf: Vec<u8> = vec![];
+    buf.extend(&bytes[..len]);
+    let (res, _) = LayoutVerified::<&[u8], T>::new_from_prefix(&buf)
+        .ok_or(ProgramError::InvalidAccountData)?;
+    return Ok(res.clone());
 }
 
 // pub fn borsh_safe_serialize<T: BorshSerialize>(state: &T, type_indicator: SwitchboardAccountType) -> Vec<u8> {
